// Copyright (C) 2021 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

#ifndef QTQUICKTIMELINEGLOBAL_H
#define QTQUICKTIMELINEGLOBAL_H

#include <QtCore/qglobal.h>
#include <QtQuickTimeline/qtquicktimelineexports.h>

#endif // QTQUICKTIMELINEGLOBAL_H
